@@ -2,13 +2,17 @@
 
 import os
 import tempfile
+from pathlib import Path
 
 import tldextract
 from tldextract.tldextract import ExtractResult
 
-FAKE_SUFFIX_LIST_URL = "file://" + os.path.join(
-    os.path.dirname(os.path.abspath(__file__)), "fixtures/fake_suffix_list_fixture.dat"
-)
+FAKE_SUFFIX_LIST_URL = Path(
+    os.path.dirname(os.path.abspath(__file__)),
+    "fixtures",
+    "fake_suffix_list_fixture.dat",
+).as_uri()
+
 EXTRA_SUFFIXES = ["foo1", "bar1", "baz1"]
 
 extract_using_fake_suffix_list = tldextract.TLDExtract(
