@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import logging
 import os
+import sys
 import tempfile
 from collections.abc import Sequence
 from pathlib import Path
@@ -17,7 +18,7 @@ import responses
 import tldextract
 import tldextract.suffix_list
 from tldextract.cache import DiskCache
-from tldextract.remote import inet_pton, lenient_netloc, looks_like_ip
+from tldextract.remote import lenient_netloc, looks_like_ip, looks_like_ipv6
 from tldextract.suffix_list import SuffixListNotFound
 from tldextract.tldextract import ExtractResult
 
@@ -152,21 +153,24 @@ def test_lenient_netloc() -> None:
     )
 
 
-@pytest.mark.skipif(not inet_pton, reason="inet_pton unavailable")
-def test_looks_like_ip_with_inet_pton() -> None:
-    """Test preferred function to check if a string looks like an IP address."""
-    assert looks_like_ip("1.1.1.1", inet_pton) is True
-    assert looks_like_ip("a.1.1.1", inet_pton) is False
-    assert looks_like_ip("1.1.1.1\n", inet_pton) is False
-    assert looks_like_ip("256.256.256.256", inet_pton) is False
+def test_looks_like_ip() -> None:
+    """Test function to check if a string looks like an IPv4 address."""
+    assert looks_like_ip("1.1.1.1") is True
+    assert looks_like_ip("1.1.1.01") is False
+    assert looks_like_ip("a.1.1.1") is False
+    assert looks_like_ip("1.1.1.1\n") is False
+    assert looks_like_ip("256.256.256.256") is False
 
 
-def test_looks_like_ip_without_inet_pton() -> None:
-    """Test fallback function to check if a string looks like an IP address."""
-    assert looks_like_ip("1.1.1.1", None) is True
-    assert looks_like_ip("a.1.1.1", None) is False
-    assert looks_like_ip("1.1.1.1\n", None) is False
-    assert looks_like_ip("256.256.256.256", None) is False
+def test_looks_like_ipv6() -> None:
+    """Test function to check if a string looks like an IPv6 address."""
+    assert looks_like_ipv6("::") is True
+    assert looks_like_ipv6("aBcD:ef01:2345:6789:aBcD:ef01:aaaa:2288") is True
+    assert looks_like_ipv6("aBcD:ef01:2345:6789:aBcD:ef01:127.0.0.1") is True
+    assert looks_like_ipv6("ZBcD:ef01:2345:6789:aBcD:ef01:127.0.0.1") is False
+    if sys.version_info >= (3, 8, 12):  # noqa: UP036
+        assert looks_like_ipv6("aBcD:ef01:2345:6789:aBcD:ef01:127.0.0.01") is False
+    assert looks_like_ipv6("aBcD:ef01:2345:6789:aBcD:") is False
 
 
 def test_similar_to_ip() -> None:
